@@ -50,7 +50,7 @@ class InstrumentWrapper(param.Parameterized):
                             print(hwid)
                             print(port.hwid.split(" ")[1].replace("VID:PID=", ""))
                         if str(hwid) == port.hwid.split(" ")[1].replace("VID:PID=", ""):
-                            if port.serial_number in module["serial"] or module["serial"] is "any":
+                            if port.serial_number in self.modules[module]["serial"] or self.modules[module]["serial"] is "any":
                                 name = f"{port.serial_number} - {port.name} - {mname} - {port.name}"
                                 self.devices[name] = {"name": port.name, "hwid": port.hwid,
                                                       "serial_number": port.serial_number, "module": module,
